isAccessibleIn2 method
- @Deprecated('Use isAccessibleIn() instead')
- @override
- LibraryElement library
inherited
Return true if this element, assuming that it is within scope, is
accessible to code in the given library. This is defined by the Dart
Language Specification in section 6.2:
A declaration m is accessible to a library L if m is declared in L or if m is public.
Implementation
@Deprecated('Use isAccessibleIn() instead')
@override
bool isAccessibleIn2(LibraryElement library) {
return isAccessibleIn(library);
}